package com.ruoyi.web.controller.learn;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.learn.domain.LearnTestPaper;
import com.ruoyi.learn.service.ILearnTestPaperService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 批次测试卷Controller
 *
 * @author ruoyi
 * @date 2025-09-18
 */
@RestController
@RequestMapping("/learn/test_paper")
@Api("后台-学习 - 批次卷管理")
public class LearnTestPaperController extends BaseController
{
    @Autowired
    private ILearnTestPaperService learnTestPaperService;

    /**
     * 查询批次测试卷列表
     */
    @PreAuthorize("@ss.hasPermi('learn:test_paper:list')")
    @GetMapping("/list")
    public TableDataInfo list(LearnTestPaper learnTestPaper)
    {
        startPage();
        List<LearnTestPaper> list = learnTestPaperService.selectLearnTestPaperList(learnTestPaper);
        return getDataTable(list);
    }

    /**
     * 导出批次测试卷列表
     */
    @PreAuthorize("@ss.hasPermi('learn:test_paper:export')")
    @Log(title = "批次测试卷", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LearnTestPaper learnTestPaper)
    {
        List<LearnTestPaper> list = learnTestPaperService.selectLearnTestPaperList(learnTestPaper);
        ExcelUtil<LearnTestPaper> util = new ExcelUtil<LearnTestPaper>(LearnTestPaper.class);
        util.exportExcel(response, list, "批次测试卷数据");
    }

    /**
     * 获取批次测试卷详细信息
     */
    @PreAuthorize("@ss.hasPermi('learn:test_paper:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(learnTestPaperService.selectLearnTestPaperById(id));
    }

    /**
     * 新增批次测试卷
     */
    @PreAuthorize("@ss.hasPermi('learn:test_paper:add')")
    @Log(title = "批次测试卷", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LearnTestPaper learnTestPaper)
    {
        return toAjax(learnTestPaperService.insertLearnTestPaper(learnTestPaper));
    }

    /**
     * 修改批次测试卷
     */
    @PreAuthorize("@ss.hasPermi('learn:test_paper:edit')")
    @Log(title = "批次测试卷", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LearnTestPaper learnTestPaper)
    {
        return toAjax(learnTestPaperService.updateLearnTestPaper(learnTestPaper));
    }

    /**
     * 删除批次测试卷
     */
    @PreAuthorize("@ss.hasPermi('learn:test_paper:remove')")
    @Log(title = "批次测试卷", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(learnTestPaperService.deleteLearnTestPaperByIds(ids));
    }
}
